@@ -6,7 +6,7 @@ use warnings;
 use Params::Validate qw(:all);
 
 use PVTests;
-use Test::More;
+use Test::More 0.88;
 
 my $String = 'foo';
 
@@ -65,6 +65,13 @@ my @Tests = (
         expect => q{},
     },
 
+    # sort missing params
+    {
+        sub    => 'sub3',
+        p      => [],
+        expect => qr|^Mandatory parameters 'bar', 'baz', 'brax', 'foo', 'quux' missing|,
+    },
+
     # simple types
     {
         sub => 'sub3',
@@ -673,12 +680,16 @@ sub run_tests {
 
         if ( eval { %{ $test->{return} } } ) {
             my %r = @r;
-            is_deeply( \%r, $test->{return},
-                "check return value for $sub - hash" );
+            is_deeply(
+                \%r, $test->{return},
+                "check return value for $sub - hash"
+            );
         }
         else {
-            is_deeply( \@r, $test->{return},
-                "check return value for $sub - array" );
+            is_deeply(
+                \@r, $test->{return},
+                "check return value for $sub - array"
+            );
         }
     }
 
